==> huaweicloudsdkces-3.1.130-py2.py3-none-any.whl: huaweicloudsdkces/v2/model/list_one_click_alarm_rules_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListOneClickAlarmRulesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'alarms': 'list[ListAlarmsRespAlarms]'
    }

    attribute_map = {
        'alarms': 'alarms'
    }

    def __init__(self, alarms=None):
        """ListOneClickAlarmRulesResponse

        The model defined in huaweicloud sdk

        :param alarms: 告警规则列表
        :type alarms: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        
        super(ListOneClickAlarmRulesResponse, self).__init__()

        self._alarms = None
        self.discriminator = None

        if alarms is not None:
            self.alarms = alarms

    @property
    def alarms(self):
        """Gets the alarms of this ListOneClickAlarmRulesResponse.

        告警规则列表

        :return: The alarms of this ListOneClickAlarmRulesResponse.
        :rtype: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        return self._alarms

    @alarms.setter
    def alarms(self, alarms):
        """Sets the alarms of this ListOneClickAlarmRulesResponse.

        告警规则列表

        :param alarms: The alarms of this ListOneClickAlarmRulesResponse.
        :type alarms: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        self._alarms = alarms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListOneClickAlarmRulesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkces-3.1.147-py2.py3-none-any.whl: huaweicloudsdkces/v2/model/list_one_click_alarm_rules_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListOneClickAlarmRulesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'alarms': 'list[ListAlarmsRespAlarms]'
    }

    attribute_map = {
        'alarms': 'alarms'
    }

    def __init__(self, alarms=None):
        r"""ListOneClickAlarmRulesResponse

        The model defined in huaweicloud sdk

        :param alarms: 告警规则列表
        :type alarms: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        
        super(ListOneClickAlarmRulesResponse, self).__init__()

        self._alarms = None
        self.discriminator = None

        if alarms is not None:
            self.alarms = alarms

    @property
    def alarms(self):
        r"""Gets the alarms of this ListOneClickAlarmRulesResponse.

        告警规则列表

        :return: The alarms of this ListOneClickAlarmRulesResponse.
        :rtype: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        return self._alarms

    @alarms.setter
    def alarms(self, alarms):
        r"""Sets the alarms of this ListOneClickAlarmRulesResponse.

        告警规则列表

        :param alarms: The alarms of this ListOneClickAlarmRulesResponse.
        :type alarms: list[:class:`huaweicloudsdkces.v2.ListAlarmsRespAlarms`]
        """
        self._alarms = alarms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListOneClickAlarmRulesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
